pub struct MarkerState {
pub ActiveCustomDocuments: Arc<Mutex<HashMap<String, CustomDocumentStateDTO>>>,
pub ActiveStatusBarItems: Arc<Mutex<HashMap<String, StatusBarEntryDTO>>>,
pub SourceControlManagementProviders: Arc<Mutex<HashMap<u32, SourceControlManagementProviderDTO>>>,
pub SourceControlManagementGroups: Arc<Mutex<HashMap<u32, HashMap<String, SourceControlManagementGroupDTO>>>>,
pub SourceControlManagementResources: Arc<Mutex<HashMap<u32, HashMap<String, Vec<SourceControlManagementResourceDTO>>>>>,
pub NextSourceControlManagementProviderHandle: Arc<AtomicU32>,
}Expand description
Marker-related state containing custom documents, status bar, and SCM state.
Fields
ActiveCustomDocuments: Arc<Mutex<HashMap<String, CustomDocumentStateDTO>>>Active custom documents organized by ID.
ActiveStatusBarItems: Arc<Mutex<HashMap<String, StatusBarEntryDTO>>>Active status bar items organized by ID.
SourceControlManagementProviders: Arc<Mutex<HashMap<u32, SourceControlManagementProviderDTO>>>SCM providers organized by handle.
SourceControlManagementGroups: Arc<Mutex<HashMap<u32, HashMap<String, SourceControlManagementGroupDTO>>>>SCM groups organized by provider handle and group ID.
SourceControlManagementResources: Arc<Mutex<HashMap<u32, HashMap<String, Vec<SourceControlManagementResourceDTO>>>>>SCM resources organized by provider handle and group ID.
NextSourceControlManagementProviderHandle: Arc<AtomicU32>Counter for generating unique SCM provider handles.
Implementations
Sourceimpl MarkerState
impl MarkerState
Sourcepub fn GetNextSourceControlManagementProviderHandle(&self) -> u32
pub fn GetNextSourceControlManagementProviderHandle(&self) -> u32
Gets the next available unique identifier for an SCM provider.
Sourcepub fn GetCustomDocuments(&self) -> HashMap<String, CustomDocumentStateDTO>
pub fn GetCustomDocuments(&self) -> HashMap<String, CustomDocumentStateDTO>
Gets all active custom documents.
Sourcepub fn AddOrUpdateCustomDocument(
&self,
id: String,
document: CustomDocumentStateDTO,
)
pub fn AddOrUpdateCustomDocument( &self, id: String, document: CustomDocumentStateDTO, )
Adds or updates a custom document.
Sourcepub fn RemoveCustomDocument(&self, id: &str)
pub fn RemoveCustomDocument(&self, id: &str)
Removes a custom document by its ID.
Sourcepub fn GetStatusBarItems(&self) -> HashMap<String, StatusBarEntryDTO>
pub fn GetStatusBarItems(&self) -> HashMap<String, StatusBarEntryDTO>
Gets all active status bar items.
Sourcepub fn AddOrUpdateStatusBarItem(&self, id: String, item: StatusBarEntryDTO)
pub fn AddOrUpdateStatusBarItem(&self, id: String, item: StatusBarEntryDTO)
Adds or updates a status bar item.
Sourcepub fn RemoveStatusBarItem(&self, id: &str)
pub fn RemoveStatusBarItem(&self, id: &str)
Removes a status bar item by its ID.